__version__ = '0.0.15'

"""

Sample settings

BLOXBY_BUILDER = {
    'url': 'http://clouddigitalmarketing.com',
    'username': 'hello@linkfusions.com',
    'password': 'accountpassword',
    'package_prefix': 'LF-',
    'account_email_prefix': 'LF',
    'public_key': 'Yourpublickeyasstatedinthebloxbyapplicationsettings',
    'autologin_hash': 'Yourautologinhash'
}

account_email_prefix: Prepended to all the emails when registering the account, just to make sure the user can use
same email for more than one app (i.e. Can maintain different accounts connected to linkfusions and also connected to
vmm at the same time).
Same applies to package_prefix for packages

"""
